@@ -32,8 +32,8 @@
 #define ARG_LONGDOUBLE	8
 #define ARG_LONGLONG	9
 
-extern char * arg_names [];
-extern char * arg_types [];
+extern const char * arg_names [];
+extern const char * arg_types [];
 
 #define ARGS_STRUCT "args_info"
 
